clone

package
v0.13.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 22, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Internal package with slightly faster, for this module, cloning function.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Slice

func Slice[Type any](slice []Type) []Type

Creates a shallow copy of a slice via the copy function. Faster on 5-30% than append on the number of items from 1 to about 128 of type int.

Types

This section is empty.

Jump to