package
Version:
v0.13.5
Opens a new window with list of versions in this module.
Published: Oct 22, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Internal package with slightly faster, for this module, cloning function.
func Slice[Type any](slice []Type) []Type
Creates a shallow copy of a slice via the copy function. Faster on 5-30% than append
on the number of items from 1 to about 128 of type int.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.